Welcome to the Krotov package's documentation!
==============================================

.. image:: https://img.shields.io/badge/github-qucontrol/krotov-blue.svg
   :alt: Source code on Github
   :target: https://github.com/qucontrol/krotov
.. image:: https://img.shields.io/pypi/v/krotov.svg
   :alt: Krotov on the Python Package Index
   :target: https://pypi.python.org/pypi/krotov
.. image:: https://badges.gitter.im/qucontrol_krotov/Lobby.svg
   :alt: Join the chat at https://gitter.im/qucontrol_krotov/Lobby
   :target: https://gitter.im/qucontrol_krotov/Lobby?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge
.. image:: https://img.shields.io/travis/qucontrol/krotov.svg
   :alt: Travis Continuous Integration
   :target: https://travis-ci.org/qucontrol/krotov
.. image:: https://ci.appveyor.com/api/projects/status/1cbm24w04jmxjpjh?svg=true
   :alt: AppVeyor Continuous Integration
   :target: https://ci.appveyor.com/project/goerz/krotov
.. image:: https://codecov.io/gh/qucontrol/krotov/branch/master/graph/badge.svg
   :alt: Codecov
   :target: https://codecov.io/gh/qucontrol/krotov
.. image:: https://img.shields.io/badge/License-BSD-green.svg
   :alt: BSD License
   :target: https://opensource.org/licenses/BSD-3-Clause
.. image:: https://readthedocs.org/projects/krotov/badge/?version=latest
   :alt: Documentation Status
   :target: https://krotov.readthedocs.io/en/latest/?badge=latest
.. image:: https://mybinder.org/badge_logo.svg
   :alt: Launch Binder
   :target: https://mybinder.org/v2/gh/qucontrol/krotov/0.4.0?filepath=docs%2Fnotebooks
.. image:: https://img.shields.io/badge/arXiv-1902.11284-red.svg
   :alt: arXiv
   :target: https://arxiv.org/abs/1902.11284


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   01_overview
   02_contributing
   03_authors
   04_features
   05_history
   06_krotovs_method
   07_qutip_usage
   08_examples
   09_howto
   10_other_methods
   99_bibliography


.. Note: the filenames of the rst files linked above are numbered 01, 02, etc
   because we have a single bibliography file for the entire documentation.
   Unfortunately, the citation numbers are assigned in the order that Sphinx
   processes the files. This is in alphabetical order, not in the order they
   appear in the toctree. Thus, numbering the files is necessary to make the
   citation number appear in the desired order.


API
===

.. toctree::
   :maxdepth: 1

   API of the Krotov package <API/krotov>

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
